@@ -1,19 +1,20 @@
 """Registers precis_i18n codec."""
 
 import codecs
+
 from precis_i18n import get_profile
 
 
 def _make_encode(profile):
-    def _encode(s, errors='strict'):
+    def _encode(input, errors='strict'):
         if errors != 'strict':
             raise ValueError('invalid errors argument')
-        return (profile.enforce(s).encode('utf-8'), len(s))
+        return (profile.enforce(input).encode('utf-8'), len(input))
 
     return _encode
 
 
-def _not_supported(s, errors='strict'):
+def _not_supported(input, errors='strict'):
     # pylint: disable=unused-argument
     raise NotImplementedError('decode not supported')
 
